@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: mysql.py 1022 2011-10-11 23:27:49Z pronovic $
 # Purpose  : Provides an extension to back up MySQL databases.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -132,7 +131,7 @@ class MysqlConfig(object):
    def __init__(self, user=None, password=None, compressMode=None, all=None, databases=None):  # pylint: disable=W0622
       """
       Constructor for the C{MysqlConfig} class.
-      
+
       @param user: User to execute backup as.
       @param password: Password associated with user.
       @param compressMode: Compress mode for backed-up files.
@@ -242,7 +241,7 @@ class MysqlConfig(object):
       """
       Property target used to get the compress mode.
       """
-      return self._compressMode 
+      return self._compressMode
 
    def _setAll(self, value):
       """
@@ -333,7 +332,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -483,7 +482,7 @@ class LocalConfig(object):
    def _parseMysql(parentNode):
       """
       Parses a mysql configuration section.
-      
+
       We read the following fields::
 
          user           //cb_config/mysql/user
@@ -543,13 +542,13 @@ def executeAction(configPath, options, config):
    local = LocalConfig(xmlPath=configPath)
    if local.mysql.all:
       logger.info("Backing up all databases.")
-      _backupDatabase(config.collect.targetDir, local.mysql.compressMode, local.mysql.user, local.mysql.password, 
+      _backupDatabase(config.collect.targetDir, local.mysql.compressMode, local.mysql.user, local.mysql.password,
                       config.options.backupUser, config.options.backupGroup, None)
    else:
-      logger.debug("Backing up %d individual databases." % len(local.mysql.databases))
+      logger.debug("Backing up %d individual databases.", len(local.mysql.databases))
       for database in local.mysql.databases:
-         logger.info("Backing up database [%s]." % database)
-         _backupDatabase(config.collect.targetDir, local.mysql.compressMode, local.mysql.user, local.mysql.password, 
+         logger.info("Backing up database [%s].", database)
+         _backupDatabase(config.collect.targetDir, local.mysql.compressMode, local.mysql.user, local.mysql.password,
                          config.options.backupUser, config.options.backupGroup, database)
    logger.info("Executed the MySQL extended action successfully.")
 
@@ -587,7 +586,7 @@ def _getOutputFile(targetDir, database, compressMode):
    Opens the output file used for saving the MySQL dump.
 
    The filename is either C{"mysqldump.txt"} or C{"mysqldump-<database>.txt"}.  The
-   C{".bz2"} extension is added if C{compress} is C{True}. 
+   C{".bz2"} extension is added if C{compress} is C{True}.
 
    @param targetDir: Target directory to write file in.
    @param database: Name of the database (if any)
@@ -607,7 +606,7 @@ def _getOutputFile(targetDir, database, compressMode):
       outputFile = BZ2File(filename, "w")
    else:
       outputFile = open(filename, "w")
-   logger.debug("MySQL dump file will be [%s]." % filename)
+   logger.debug("MySQL dump file will be [%s].", filename)
    return (outputFile, filename)
 
 
@@ -661,7 +660,7 @@ def backupDatabase(user, password, backupFile, database=None):
 
    @param backupFile: File use for writing backup.
    @type backupFile: Python file object as from C{open()} or C{file()}.
-   
+
    @param database: Name of the database to be backed up.
    @type database: String representing database name, or C{None} for all databases.
 
