@@ -27,7 +27,7 @@
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 #            Antoine Beaupre <anarcat@koumbit.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
 # Purpose  : Provides an extension to back up PostgreSQL databases.
 #
@@ -122,7 +122,7 @@ class PostgresqlConfig(object):
    def __init__(self, user=None, compressMode=None, all=None, databases=None):  # pylint: disable=W0622
       """
       Constructor for the C{PostgresqlConfig} class.
-      
+
       @param user: User to execute backup as.
       @param compressMode: Compress mode for backed-up files.
       @param all: Indicates whether to back up all databases.
@@ -209,7 +209,7 @@ class PostgresqlConfig(object):
       """
       Property target used to get the compress mode.
       """
-      return self._compressMode 
+      return self._compressMode
 
    def _setAll(self, value):
       """
@@ -299,7 +299,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -447,7 +447,7 @@ class LocalConfig(object):
    def _parsePostgresql(parent):
       """
       Parses a postgresql configuration section.
-      
+
       We read the following fields::
 
          user           //cb_config/postgresql/user
@@ -508,9 +508,9 @@ def executeAction(configPath, options, config):
       _backupDatabase(config.collect.targetDir, local.postgresql.compressMode, local.postgresql.user,
                       config.options.backupUser, config.options.backupGroup, None)
    if local.postgresql.databases is not None and local.postgresql.databases != []:
-      logger.debug("Backing up %d individual databases." % len(local.postgresql.databases))
+      logger.debug("Backing up %d individual databases.", len(local.postgresql.databases))
       for database in local.postgresql.databases:
-         logger.info("Backing up database [%s]." % database)
+         logger.info("Backing up database [%s].", database)
          _backupDatabase(config.collect.targetDir, local.postgresql.compressMode, local.postgresql.user,
                          config.options.backupUser, config.options.backupGroup, database)
    logger.info("Executed the PostgreSQL extended action successfully.")
@@ -549,7 +549,7 @@ def _getOutputFile(targetDir, database, compressMode):
 
    The filename is either C{"postgresqldump.txt"} or
    C{"postgresqldump-<database>.txt"}.  The C{".gz"} or C{".bz2"} extension is
-   added if C{compress} is C{True}. 
+   added if C{compress} is C{True}.
 
    @param targetDir: Target directory to write file in.
    @param database: Name of the database (if any)
@@ -569,7 +569,7 @@ def _getOutputFile(targetDir, database, compressMode):
       outputFile = BZ2File(filename, "w")
    else:
       outputFile = open(filename, "w")
-   logger.debug("PostgreSQL dump file will be [%s]." % filename)
+   logger.debug("PostgreSQL dump file will be [%s].", filename)
    return (outputFile, filename)
 
 
@@ -598,7 +598,7 @@ def backupDatabase(user, backupFile, database=None):
 
    @param backupFile: File use for writing backup.
    @type backupFile: Python file object as from C{open()} or C{file()}.
-   
+
    @param database: Name of the database to be backed up.
    @type database: String representing database name, or C{None} for all databases.
 
@@ -609,13 +609,13 @@ def backupDatabase(user, backupFile, database=None):
    if user is not None:
       args.append('-U')
       args.append(user)
-   
+
    if database is None:
       command = resolveCommand(POSTGRESQLDUMPALL_COMMAND)
    else:
       command = resolveCommand(POSTGRESQLDUMP_COMMAND)
       args.append(database)
-   
+
    result = executeCommand(command, args, returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=backupFile)[0]
    if result != 0:
       if database is None:
